@@ -2,7 +2,7 @@ package Spreadsheet::XLSX::Reader::LibXML::Types;
 BEGIN {
   $Spreadsheet::XLSX::Reader::LibXML::Types::AUTHORITY = 'cpan:JANDREW';
 }
-use version; our $VERSION = qv('v0.30.2');
+use version; our $VERSION = qv('v0.32.2');
 		
 use strict;
 use warnings;
@@ -14,7 +14,7 @@ use Type::Library 0.046
 		ParserType					Excel_number_0				EpochYear
 		PassThroughType				CellID						PositiveNum
 		NegativeNum					ZeroOrUndef					NotNegativeNum
-		IOFileType
+		IOFileType					ErrorString					SubString
 	);
 use IO::File;
 BEGIN{ extends "Types::Standard" };
@@ -117,6 +117,33 @@ declare NotNegativeNum,
 	as Num,
 	where{ $_ > -1 };
 
+declare SubString,
+	as Str;
+
+declare ErrorString,
+	as SubString,
+	where{ $_ !~ /\)\n;/ };
+	
+coerce SubString,
+	from Object,
+	via{ 
+	my	$object = $_;
+		if( $object->can( 'as_string' ) ){
+			return $object->as_string;
+		}elsif( $object->can( 'message' ) ){
+			return $object->message;
+		}
+		return $object;
+	};
+	
+coerce ErrorString,
+	from SubString->coercibles,
+	via{
+	my	$tmp = to_SubString($_);
+		$tmp =~ s/\)\n;/\);/g;
+		return $tmp;
+	};
+
 
 #########1 Excel Defined Converions     4#########5#########6#########7#########8#########9
 
@@ -132,7 +159,8 @@ declare_coercion Excel_number_0,
 	
 
 #########1 Phinish            3#########4#########5#########6#########7#########8#########9
-	
+
+__PACKAGE__->meta->make_immutable;
 1;
 
 #########1 Documentation      3#########4#########5#########6#########7#########8#########9
@@ -165,7 +193,7 @@ L<github Spreadsheet::XLSX::Reader::LibXML/issues
 
 =over
 
-B<1.> Nothing L<yet|/SUPPORT>
+B<1.> Add ErrorString type tests to the test suit
 
 =back
 
